#
##
##  SPDX-FileCopyrightText: © 2007-2021 Benedict Verhegghe <bverheg@gmail.com>
##  SPDX-License-Identifier: GPL-3.0-or-later
##
##  This file is part of pyFormex 2.6  (Mon Aug 23 15:13:50 CEST 2021)
##  pyFormex is a tool for generating, manipulating and transforming 3D
##  geometrical models by sequences of mathematical operations.
##  Home page: https://pyformex.org
##  Project page: https://savannah.nongnu.org/projects/pyformex/
##  Development: https://gitlab.com/bverheg/pyformex
##  Distributed under the GNU General Public License version 3 or later.
##
##  This program is free software: you can redistribute it and/or modify
##  it under the terms of the GNU General Public License as published by
##  the Free Software Foundation, either version 3 of the License, or
##  (at your option) any later version.
##
##  This program is distributed in the hope that it will be useful,
##  but WITHOUT ANY WARRANTY; without even the implied warranty of
##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##  GNU General Public License for more details.
##
##  You should have received a copy of the GNU General Public License
##  along with this program.  If not, see http://www.gnu.org/licenses/.
##
"""Menus for the pyFormex GUI.

This modules implements specialized classes and functions for building
the pyFormex GUI menu system.
"""

from gettext import gettext as _

import pyformex as pf
from pyformex import (
    utils, script,
    )
from pyformex.gui import (
    QtGui, QtCore, Signal,
    toolbar, image, draw,
    )

from collections import OrderedDict


# The menu actions can be simply function names instead of strings, if the
# functions have already been defined here.

def printwindow():
    #pf.app.syncX()
    r = pf.GUI.XGeometry()
    print(f"Qt geom(w,h,x,y): {r}")


_geometry=None

def saveGeometry():
    global _geometry
    _geometry = pf.GUI.saveGeometry()

def restoreGeometry():
    pf.GUI.restoreGeometry(_geometry)

def closeLogFile():
    if draw.logfile:
        draw.logfile.close()
        draw.logfile = None

def openLogFile():
    fn = draw.askFilename(filter=['*.log', '*'])
    if fn:
        closeLogFile()
        draw.logfile = open(fn, 'w')


def saveBoard():
    fn = draw.askFilename(filter=['*.txt', '*'])
    if fn:
        pf.GUI.board.save(fn)


def clearBoard():
    pf.GUI.board.clear()


def unloadCurrentApp():
    appname = pf.cfg['curfile']
    from pyformex import apps
    apps.unload(appname)


def printSysPath():
    import sys
    print(sys.path)


def printModules():
    import sys
    print(sorted(sys.modules.keys()))


def printLastCommand():
    """Print a nice report of the outcome of the last command"""
    print('=' * 8 + " LAST COMMAND REPORT " + '=' * 21)
    print(utils.last_command)
    print('=' * 50)


MenuData = (_('&Actions'), [
    (_('&Play'), draw.play),
    (_('&Rerun'), draw.replay),
    ## (_('&Step'),draw.step),
    (_('&Continue'), draw.fforward),
    (_('&Stop'), draw.raiseExit),
    ("---", None),
    (_('&App Info'), draw.showDoc),
    ("---", None),
    ## (_('&Reset Picking Mode'),resetPick),
    (_('&Reset GUI'), draw.resetGUI),
    (_('&Force Finish Script'), script.force_finish),
    (_('&Unload Current App'), unloadCurrentApp),
    ## (_('&Execute single statement'),command),
    (_('&Save Message Board'), saveBoard),
    (_('&Clear Message Board'), clearBoard),
    (_('&Open Log File'), openLogFile),
    (_('&Close Log File'), closeLogFile),
    (_('&Print Config'), script.printConfig),
    (_('&Print Last Command'), printLastCommand),
    (_('&Print Loaded Apps'), script.printLoadedApps),
    (_('&Print sys.path'), printSysPath),
    (_('&Print loaded modules'), printModules),
    #(_('&Print Used Memory'), script.printVMem),
    (_('&Print Bbox'), draw.printbbox),
    (_('&Print Viewport Settings'), draw.printviewportsettings),
    (_('&Print Window Geometry'), printwindow),
    (_('&Save Geometry'), saveGeometry),
    (_('&Restore Geometry'), restoreGeometry),
    (_('&Toggle Input Timeout'), toolbar.timeout),
    ])


# End
